@@ -52,24 +52,20 @@ class Parser:
         return paths
 
     def getResolvedPaths(self):
-        def removeMkdocsYmlFromPath(path):
-            rootDir = os.path.normpath(os.path.join(
-                os.getcwd(), self.config['config_file_path'], '../'))
-            absPath = os.path.normpath(os.path.join(
-                # Remove config file name from path, match any *.yml file
-                rootDir, re.sub(r'(.*)\/.*\.yml$', r'\1', path, re.IGNORECASE)))
-            return absPath
-
+        """Return list of [alias, docs_dir, mkdocs.yml]."""
         def extractAliasAndPath(absPath):
-            return [IncludeNavLoader(self.config, absPath).read().getAlias(), removeMkdocsYmlFromPath(absPath)]
+            loader = IncludeNavLoader(self.config, absPath).read()
+            alias = loader.getAlias()
+            docsDir = os.path.join(loader.rootDir, os.path.dirname(absPath), loader.getDocsDir())
+            return [alias, docsDir, os.path.join(loader.rootDir, absPath)]
 
         resolvedPaths = list(
             map(extractAliasAndPath, self.__loadAliasesAndResolvedPaths()))
 
-        for alias, resolvedPath in resolvedPaths:
-            if not os.path.exists(resolvedPath):
+        for alias, docsDir, ymlPath in resolvedPaths:
+            if not os.path.exists(docsDir):
                 log.critical(
-                    "[mkdocs-monorepo] The {} path is not valid. ".format(resolvedPath) +
+                    "[mkdocs-monorepo] The {} path is not valid. ".format(docsDir) +
                     "Please update your 'nav' with a valid path.")
                 raise SystemExit(1)
 
@@ -165,6 +161,9 @@ class IncludeNavLoader:
 
         return self
 
+    def getDocsDir(self):
+        return self.navYaml.get("docs_dir", "docs")
+
     def getAlias(self):
         alias = self.navYaml["site_name"]
         regex = '^[a-zA-Z0-9_\-/]+$'  # noqa: W605
